@@ -10,7 +10,7 @@ import time
 import warnings
 import numpy as np
 from numba import jit, generated_jit, types
-from .game_theory.lemke_howson import lemke_howson_tbl, get_mixed_actions
+from .game_theory.lemke_howson import _lemke_howson_tbl, _get_mixed_actions
 
 
 def _print_after_skip(skip, it=None, dist=None, etime=None):
@@ -48,13 +48,13 @@ def _is_approx_fp(T, v, error_tol, *args, **kwargs):
 
 def compute_fixed_point(T, v, error_tol=1e-3, max_iter=50, verbose=2,
                         print_skip=5, method='iteration', *args, **kwargs):
-    """
+    r"""
     Computes and returns an approximate fixed point of the function `T`.
 
     The default method `'iteration'` simply iterates the function given
     an initial condition `v` and returns :math:`T^k v` when the
     condition :math:`\lVert T^k v - T^{k-1} v\rVert \leq
-    \mathrm{error_tol}` is satisfied or the number of iterations
+    \mathrm{error\_tol}` is satisfied or the number of iterations
     :math:`k` reaches `max_iter`. Provided that `T` is a contraction
     mapping or similar, :math:`T^k v` will be an approximation to the
     fixed point.
@@ -65,7 +65,7 @@ def compute_fixed_point(T, v, error_tol=1e-3, max_iter=50, verbose=2,
     their Nash equilibria, computed by the Lemke-Howson algorithm
     routine. It finds an approximate fixed point of `T`, a point
     :math:`v^*` such that :math:`\lVert T(v) - v\rVert \leq
-    \mathrm{error_tol}`, provided `T` is a function that satisfies the
+    \mathrm{error\_tol}`, provided `T` is a function that satisfies the
     assumptions of Brouwer's fixed point theorm, i.e., a continuous
     function that maps a compact and convex set to itself.
 
@@ -86,9 +86,9 @@ def compute_fixed_point(T, v, error_tol=1e-3, max_iter=50, verbose=2,
     print_skip : scalar(int), optional(default=5)
         How many iterations to apply between print messages (effective
         only when `verbose=2`)
-    method : str in {'iteration', 'imitation_game'},
-             optional(default='iteration')
-        Method of computing an approximate fixed point
+    method : str, optional(default='iteration')
+        str in {'iteration', 'imitation_game'}. Method of computing
+        an approximate fixed point
     args, kwargs :
         Other arguments and keyword arguments that are passed directly
         to  the function T each time it is called
@@ -225,7 +225,7 @@ def _compute_fixed_point_ig(T, v, max_iter, verbose, print_skip, is_approx_fp,
 
     tableaux = tuple(np.empty((buff_size, buff_size*2+1)) for i in range(2))
     bases = tuple(np.empty(buff_size, dtype=int) for i in range(2))
-    max_piv = 10**6  # Max number of pivoting steps in lemke_howson_tbl
+    max_piv = 10**6  # Max number of pivoting steps in _lemke_howson_tbl
 
     while True:
         y_new = T(x_new, *args, **kwargs)
@@ -259,10 +259,10 @@ def _compute_fixed_point_ig(T, v, max_iter, verbose, print_skip, is_approx_fp,
         tableaux_curr = tuple(tableau[:m, :2*m+1] for tableau in tableaux)
         bases_curr = tuple(basis[:m] for basis in bases)
         _initialize_tableaux_ig(X[:m], Y[:m], tableaux_curr, bases_curr)
-        converged, num_iter = lemke_howson_tbl(
+        converged, num_iter = _lemke_howson_tbl(
             tableaux_curr, bases_curr, init_pivot=m-1, max_iter=max_piv
         )
-        _, rho = get_mixed_actions(tableaux_curr, bases_curr)
+        _, rho = _get_mixed_actions(tableaux_curr, bases_curr)
 
         if Y.ndim <= 2:
             x_new = rho.dot(Y[:m])
@@ -290,7 +290,7 @@ def _initialize_tableaux_ig(X, Y, tableaux, bases):
     """
     Given sequences `X` and `Y` of ndarrays, initialize the tableau and
     basis arrays in place for the "geometric" imitation game as defined
-    in McLennan and Tourky (2006), to be passed to `lemke_howson_tbl`.
+    in McLennan and Tourky (2006), to be passed to `_lemke_howson_tbl`.
 
     Parameters
     ----------
@@ -364,7 +364,7 @@ def _square_sum(a):
         return _square_sum_array
 
 
-def _square_sum_array(a):
+def _square_sum_array(a):  # pragma: no cover
     sum_ = 0
     for x in a.flat:
         sum_ += x**2
