@@ -74,17 +74,18 @@ def smooth(x, window_len=7, window='hanning'):
 
 
 def periodogram(x, window=None, window_len=7):
-    """
+    r"""
     Computes the periodogram
 
     .. math::
 
-        I(w) = (1 / n) | sum_{t=0}^{n-1} x_t e^{itw} |^2
+        I(w) = \frac{1}{n} \Big[ \sum_{t=0}^{n-1} x_t e^{itw} \Big] ^2
 
-    at the Fourier frequences w_j := 2 pi j / n, j = 0, ..., n - 1,
-    using the fast Fourier transform.  Only the frequences w_j in [0,
-    pi] and corresponding values I(w_j) are returned.  If a window type
-    is given then smoothing is performed.
+    at the Fourier frequences :math:`w_j := \frac{2 \pi j}{n}`,
+    :math:`j = 0, \dots, n - 1`, using the fast Fourier transform. Only the
+    frequences :math:`w_j` in :math:`[0, \pi]` and corresponding values
+    :math:`I(w_j)` are returned. If a window type is given then smoothing
+    is performed.
 
     Parameters
     ----------
@@ -139,19 +140,18 @@ def ar_periodogram(x, window='hanning', window_len=7):
 
     """
     # === run regression === #
-    x_lag = x[:-1] # lagged x
-    X = np.array([np.ones(len(x_lag)), x_lag]).T # add constant
-    
-    y = np.array(x[1:]) # current x
-    
-    beta_hat = np.linalg.solve(X.T @ X, X.T @ y) # solve for beta hat
-    e_hat = y - X @ beta_hat # compute residuals
-    phi = beta_hat[1] # pull out phi parameter
+    x_lag = x[:-1]  # lagged x
+    X = np.array([np.ones(len(x_lag)), x_lag]).T  # add constant
+
+    y = np.array(x[1:])  # current x
+
+    beta_hat = np.linalg.solve(X.T @ X, X.T @ y)  # solve for beta hat
+    e_hat = y - X @ beta_hat  # compute residuals
+    phi = beta_hat[1]  # pull out phi parameter
 
     # === compute periodogram on residuals === #
     w, I_w = periodogram(e_hat, window=window, window_len=window_len)
 
-
     # === compute periodogram on residuals === #
     w, I_w = periodogram(e_hat, window=window, window_len=window_len)
 
