@@ -36,10 +36,10 @@ SCC that corresponds to a sink node in the *condensation* of the
 directed graph :math:`\Gamma(P)`, where the condensation of
 :math:`\Gamma(P)` is a directed graph in which each SCC is replaced with
 a single node and there is an edge from one SCC :math:`C` to another SCC
-:math:`C'` if :math:`C \neq C'` and some node in :math:`C` has access to
-some node in :math:`C'`. A recurrent class is also called a *closed
-communication class*. The condensation is acyclic, so that there exists
-at least one recurrent class.
+:math:`C'` if :math:`C \neq C'` and there is an edge from some node in
+:math:`C` to some node in :math:`C'`. A recurrent class is also called a
+*closed communication class*. The condensation is acyclic, so that there
+exists at least one recurrent class.
 
 For example, if the entries of :math:`P` are all strictly positive, then
 the whole state space is a communication class as well as a recurrent
@@ -474,12 +474,8 @@ class MarkovChain:
         Returns
         -------
         X : ndarray(ndim=1 or 2)
-            Array containing the sample path(s), of shape (ts_length,)
-            if init is a scalar (integer) or None and num_reps is None;
-            of shape (k, ts_length) otherwise, where k = len(init) if
-            (init, num_reps) = (array, None), k = num_reps if (init,
-            num_reps) = (int or None, int), and k = len(init)*num_reps
-            if (init, num_reps) = (array, int).
+            Array containing the state values of the sample path(s). See
+            the `simulate` method for more information.
 
         """
         random_state = check_random_state(random_state)
@@ -565,8 +561,12 @@ class MarkovChain:
         Returns
         -------
         X : ndarray(ndim=1 or 2)
-            Array containing the state values of the sample path(s). See
-            the `simulate` method for more information.
+            Array containing the sample path(s), of shape (ts_length,)
+            if init is a scalar (integer) or None and num_reps is None;
+            of shape (k, ts_length) otherwise, where k = len(init) if
+            (init, num_reps) = (array, None), k = num_reps if (init,
+            num_reps) = (int or None, int), and k = len(init)*num_reps
+            if (init, num_reps) = (array, int).
 
         """
         if init is not None:
